%define debug_package %{nil}

Summary:	Open source deep packet inspection

Packager:	Lawrence R. Rogers (lrr@cert.org)

Vendor:		cert.org
Name:		nDPI
Version:	2.9.0
Release:	1%{?dist}

License:	GPL

Group:		Applications/Forensics Tools
Source:		%{name}-%{version}.tar.gz
URL:		http://www.ntop.org/products/ndpi/

BuildRoot:	%{_tmppath}/rpm-root-%{name}-v%{version}
BuildRequires:	autoconf
BuildRequires:	automake
BuildRequires:	libtool
BuildRequires:	gettext-devel
BuildRequires:	libpcap-devel

%description
nDPI is a ntop-maintained superset of the popular OpenDPI
library. Released under the GPL license, its goal is to extend the
original library by adding new protocols that are otherwise available
only on the paid version of OpenDPI. In addition to Unix platforms,
we also support Windows, in order to provide you a cross-platform DPI
experience. Furthermore, we have modified nDPI do be more suitable for
traffic monitoring applications, by disabling specific features that
slow down the DPI engine while being them un-necessary for network
traffic monitoring.

nDPI is used by both ntop and nProbe for adding application-layer
detection of protocols, regardless of the port being used. This means
that it is possible to both detect known protocols on non-standard
ports (e.g. detect http non ports other than 80), and also the opposite
(e.g. detect Skype traffic on port 80). This is because nowadays the
concept of port=application no longer holds.

%package	devel
Summary:	Header files and libraries for developing applications for nDPI
Group:		Development/Libraries
Requires:	nDPI = %{version}-%{release}

%description	devel
These are the header files and libraries for developing applications for nDPI.

%prep
%setup

%build
sh autogen.sh --with-pid --includedir=%{_includedir}/libndpi --libdir=%{_libdir}
%{__make}

%install
%makeinstall SUBDIRS=src/lib pkgconfigdir=%{buildroot}%{_libdir}/pkgconfig includedir=%{buildroot}%{_includedir}/libndpi
ln -s libndpi %{buildroot}%{_includedir}/ndpi
cp -p src/lib/third_party/include/libcache.h %{buildroot}%{_includedir}/libndpi
install -d %{buildroot}%{_bindir}
install -p -m 755 example/ndpiReader %{buildroot}%{_bindir}

%clean
%{__rm} -rf %{buildroot}

%files
%defattr(-, root, root, 0755)
%doc CHANGELOG.md COPYING INSTALL README.md README.nDPI README.protocols doc/nDPI_QuickStartGuide.pdf
%{_libdir}/libndpi.so.?
%attr(0644, root, root)	%{_libdir}/libndpi.so.*.*.*
%attr(0644, root, root)	%{_libdir}/pkgconfig/libndpi.pc
%attr(0755, root, root)	%{_bindir}/ndpiReader

%files devel
%attr(0444, root, root)	%{_includedir}/libndpi/*.h
%{_includedir}/ndpi
%attr(0644, root, root)	%{_libdir}/libndpi.a
%{_libdir}/libndpi.so

%changelog
* Mon Apr  1 2019 Lawrence R. Rogers <lrr@cert.org> 2.9.0-1
* Release 2.9.0-1
	Version 2.9.0

* Sat Dec 22 2018 Lawrence R. Rogers <lrr@cert.org> 2.6.0-1
* Release 2.6.0-1
	Version 2.6.0

* Sun Dec  3 2017 Lawrence R. Rogers <lrr@cert.org> 2.3.0-1
* Release 2.3.0-1
	Version 2.3.0

* Mon May 15 2017 Lawrence R. Rogers <lrr@cert.org> 2.0-1
* Release 2.0-1
	Version 2.0

* Mon May  8 2017 Lawrence R. Rogers <lrr@cert.org> 1.8-3
* Release 1.8-3
	Fixed a dependency problem on CentOS/RHEL 6 x86_64 where pf_ring was installed
	 and created a dependency problem when pfring-6.6.0 was installed.

* Tue Mar 28 2017 Lawrence R. Rogers <lrr@cert.org> 1.8-2
* Release 1.8-2
	Version 1.8 - patched upto 20170328.

* Wed Jun 29 2016 Lawrence R. Rogers <lrr@cert.org> 1.8-1
* Release 1.8-1
	Version 1.8

* Wed Jan  6 2016 Lawrence R. Rogers <lrr@cert.org> 1.7.1-1
* Release 1.7.1-1
	Version 1.7.1

* Mon Aug 17 2015 Lawrence R. Rogers <lrr@cert.org> 1.7-1
* Release 1.7-1
	Version 1.7

* Sun May 31 2015 Lawrence R. Rogers <lrr@cert.org> 1.6-1
* Release 1.6-1
	Version 1.6

* Tue May 13 2014 Lawrence R. Rogers <lrr@cert.org> 1.4.0.1-1
* Release 1.4.0.1-1
	2014-03-21:
		- improved support for eDonkey/eMule/Kademlia
		- improved support for PPLive

	2014-03-20:
		- code optimizations
		- consistency improvements
		- added support for new applications: Pando Media Booster
		- improved support for Steam
		- added support for new web services: Wikipedia, MSN, Amazon, eBay, CNN

	2014-03-19:
		- added new protocols: FTP, code improvements

	2014-03-17:
		- added new protocols: SOCKSv4, SOCKSv5, RTMP

* Tue Oct 18 2011 Lawrence R. Rogers <lrr@cert.org> 1.4.0-1
* Release 1.4.0-1
  * Unknown changes

* Thu Jun 9 2011 Lawrence R. Rogers <lrr@cert.org> 1.3-1
* Release 1.3-1
  * added IPv6 support
  * new protocols: DHCPv6, ICMPv6, Activesync, Armagetron, Crossfire, Dofus, Fiesta Online, Florensia, Guildwars, Kerberos,
                   LDAP, Maplestory, MSSQL, PPTP, Warcraft 3, World of Kung Fu
  * improved protocols: Aimini, Battlefield, Bittorrent, DirectDownloadLink, eDonkey, FTP, GaduGadu, Gnutella, HTTP, Icecast,
                        Imesh, IRC, Jabber, IMAP, POP, SMTP, MDNS, Meebo, MSN, Netbios, Oscar, PPLive, QQ, Quake, RTP,
                        Secondlive, Shoutcast, SIP, SSL, STUN, Syslog, TVUplayer, Veohtv, World of Warcraft, Yahoo
  * added protocol history/real protocol feature
  * various improvements and fixes

* Wed Apr 7 2010 Lawrence R. Rogers <lrr@cert.org> 1.2-1
* Release 1.2-1
  * added new protocol Meebo
  * various improvements and fixes

* Wed Nov 11 2009 Lawrence R. Rogers <lrr@cert.org> 1.1.1-1
* Release 1.1.1-1
  * fixed a compilation error that occurred when debug messages were enabled

* Tue Nov 10 2009 Lawrence R. Rogers <lrr@cert.org> 1.1-1
* Release 1.1-1
  * OpenDPI is now built using autotools
  * OpenDPI now compiles on BSD-like systems
  * added 4 new protocols (AFP, Aimini, Stealthnet, TFTP)
  * Bittorrent detection has been fixed
  * FTP detection has been fixed
  * various small improvements and fixes

* Mon Sep 7 2009 Lawrence R. Rogers <lrr@cert.org> 1.0-1
* Release 1.0-1
  * initial release

